.. File auto-generated by ``generate_summary_table.py``

.. tabularcolumns:: |p{2cm}|p{13cm}|p{5cm}|

.. list-table:: Geo2Grid Writer Summary Table
    :header-rows: 1

    * - **Writer Name**
      - **Output Filename Pattern**
      - **Output Format**
    * - geotiff
      - ``GOES-??_ABI_Rad?_C??_YYYYMMDD_HHMMSS_*.tif``

        **Ex: GOES-16_ABI_RadF_C03_20181112_183034_GOES-East.tif**
      - 8-bit single band GeoTIFF
    * - geotiff
      - ``HIMAWARI-8_AHI_B??_YYYYMMDD_HHMMSS_*.tif``

        **Ex: HIMAWARI-8_AHI_B03_20181112_183020_FLDK.tif**
      - 8-bit single band GeoTIFF
    * - geotiff
      - ``GEO-KOMPSAT-2A_AMI_?????_YYYYMMDD_HHMMSS_ami_geos_fd.tif``

        **Ex: GEO-KOMPSAT-2A_AMI_VI006_20190930_030031_ami_geos_fd.tif**
      - 8-bit single band GeoTIFF
    * - geotiff
      - ``FY-4A_AGRI_C??_YYYYMMDD_HHMMSS_DISK_????m.tif``

        **Ex: FY-4A_AGRI_C07_20220120_040004_DISK_2000m.tif**

        **Ex: FY-4B_AGRI_C11_20221115_030002_DISK_4000m.tif**
      - 8-bit single band GeoTIFF
    * - geotiff
      - ``GOES-17_ABI_????_YYYYMMDD_HHMMSS_GOES-West.tif``

        **Ex: GOES-17_ABI_TEMP_20221123_183031_GOES-West.tif**

        **Ex: GOES-17_ABI_HT_20221123_183031_GOES-West.tif**
      - 8-bit single band color enhanced GeoTIFF
    * - geotiff
      - ``GOES-18_GLM_{PRODUCT}_YYYYMMDD_HHMMSS_GOES-West.tif``

        **Ex: GOES-18_GLM_group_extent_density_20221110_190000_GOES-West.tif**
      - 8-bit single band GeoTIFF
